@@ -1,4 +1,4 @@
 library(testthat)
 library(coinmarketcapr)
 
-test_check("coinmarketcapr")
+#test_check("coinmarketcapr")
